import React, { useState, useEffect } from 'react';
import { Cpu, Mail, Phone, Building2, ChevronRight, CircuitBoard, Send, User, MessageSquare, Code, Brain, Network, Bot, Sparkles, ExternalLink, Globe, Smartphone, Laptop, X, ToggleLeft as Toggle, MessageCircle, Facebook, Twitter, Instagram, Linkedin, ArrowUpCircle, Crown, Shield, Clock, Award } from 'lucide-react';
import { z } from 'zod';

function Hero() {
  return (
    <section className="relative min-h-screen flex flex-col items-center justify-center overflow-hidden py-20">
      <div className="hero-content text-center max-w-4xl mx-auto px-4">
        <div className="mb-6">
          <Crown className="w-16 h-16 mx-auto text-yellow-400 animate-float" />
        </div>
        <h1 className="text-6xl md:text-8xl font-bold mb-8 bg-clip-text text-transparent bg-gradient-to-r from-emerald-400 via-yellow-300 to-emerald-400 animate-text-shimmer">
          PRIMAL AI
        </h1>
        <p className="text-2xl md:text-3xl text-gray-300 mb-6 font-light">
          Where Elite Innovation Meets Unparalleled Intelligence
        </p>
        <p className="text-lg text-gray-400 mb-12 max-w-2xl mx-auto">
          Join an exclusive circle of visionaries who demand nothing less than excellence. 
          Our bespoke AI solutions redefine what's possible in digital transformation.
        </p>
        <div className="flex flex-col sm:flex-row gap-6 justify-center items-center">
          <button 
            onClick={() => document.getElementById('contact-section')?.scrollIntoView({ behavior: 'smooth' })}
            className="luxury-button group"
          >
            <Crown className="w-5 h-5" />
            <span>Begin Your Elite Journey</span>
            <ChevronRight className="w-6 h-6 group-hover:translate-x-1 transition-transform duration-300" />
          </button>
          <button
            onClick={() => document.getElementById('core-offerings')?.scrollIntoView({ behavior: 'smooth' })}
            className="luxury-button-secondary group"
          >
            <span>Explore Our Expertise</span>
            <ExternalLink className="w-5 h-5 group-hover:translate-x-1 transition-transform duration-300" />
          </button>
        </div>
      </div>
      
      {/* Trust Indicators */}
      <div className="absolute bottom-12 left-0 right-0">
        <div className="max-w-4xl mx-auto px-4">
          <div className="flex justify-center items-center gap-12 text-gray-400">
            <div className="flex items-center gap-2">
              <Shield className="w-5 h-5 text-emerald-400" />
              <span className="text-sm">Enterprise-Grade Security</span>
            </div>
            <div className="flex items-center gap-2">
              <Clock className="w-5 h-5 text-emerald-400" />
              <span className="text-sm">24/7 Priority Support</span>
            </div>
            <div className="flex items-center gap-2">
              <Award className="w-5 h-5 text-emerald-400" />
              <span className="text-sm">Industry Leading Innovation</span>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
}

function ServiceCard({ icon: Icon, title, description, index, features }: { 
  icon: React.ElementType, 
  title: string, 
  description: string, 
  index: number,
  features: string[]
}) {
  const scrollToContact = () => {
    const contactSection = document.getElementById('contact-section');
    if (contactSection) {
      // Add a class to highlight the contact section temporarily
      contactSection.classList.add('highlight-section');
      
      // Smooth scroll to contact section
      contactSection.scrollIntoView({ 
        behavior: 'smooth',
        block: 'start'
      });
      
      // Remove highlight class after animation
      setTimeout(() => {
        contactSection.classList.remove('highlight-section');
      }, 2000);
    }
  };

  return (
    <div 
      className="relative group"
      style={{ 
        animationDelay: `${index * 0.2}s`,
      }}
    >
      {/* Outer glow effect */}
      <div className="absolute -inset-0.5 bg-gradient-to-r from-emerald-600 to-yellow-500 rounded-xl opacity-0 group-hover:opacity-100 blur-2xl transition-all duration-700 group-hover:duration-500" />
      
      {/* Inner glow effect */}
      <div className="absolute -inset-0.5 bg-gradient-to-r from-emerald-600 to-yellow-500 rounded-xl opacity-0 group-hover:opacity-50 blur transition-all duration-700 group-hover:duration-500" />
      
      {/* Main card content */}
      <div className="relative p-8 rounded-xl bg-black/80 border border-emerald-600/20 backdrop-blur-sm 
                    transform transition-all duration-700 group-hover:scale-[1.02] group-hover:border-yellow-500/30
                    hover:shadow-[0_0_2rem_0.5rem_rgba(16,185,129,0.1)]">
        {/* Icon container with glow */}
        <div className="relative mb-6">
          <div className="absolute inset-0 bg-gradient-to-br from-emerald-600/20 to-yellow-500/20 rounded-lg blur-xl opacity-0 group-hover:opacity-100 transition-opacity duration-700" />
          <div className="relative w-14 h-14 rounded-lg bg-gradient-to-br from-emerald-600/10 to-yellow-500/10 
                        flex items-center justify-center transform group-hover:scale-110 transition-transform duration-700">
            <Icon className="w-8 h-8 text-emerald-400 group-hover:text-yellow-400 transition-colors duration-700" />
          </div>
        </div>

        {/* Title with glow effect */}
        <h3 className="text-xl font-bold mb-4 bg-clip-text text-transparent bg-gradient-to-r 
                     from-emerald-400 to-yellow-400 group-hover:from-yellow-400 group-hover:to-emerald-400 
                     transition-all duration-700">
          {title}
        </h3>

        {/* Description with enhanced contrast */}
        <p className="text-gray-400 group-hover:text-gray-300 mb-6 transition-colors duration-700">
          {description}
        </p>

        {/* Feature list */}
        <ul className="space-y-3 mb-6">
          {features.map((feature, i) => (
            <li key={i} className="flex items-center gap-2 text-sm text-gray-400 group-hover:text-gray-300">
              <ChevronRight className="w-4 h-4 text-emerald-400 group-hover:text-yellow-400" />
              <span>{feature}</span>
            </li>
          ))}
        </ul>
        
        {/* Learn More Link */}
        <button 
          onClick={scrollToContact}
          className="flex items-center gap-2 text-emerald-400 hover:text-yellow-400 transition-all duration-300 group/link"
        >
          <span className="text-sm font-medium relative">
            Learn More
            <span className="absolute left-0 bottom-0 w-0 h-0.5 bg-yellow-400 group-hover/link:w-full transition-all duration-300" />
          </span>
          <ExternalLink className="w-4 h-4 transform group-hover/link:translate-x-1 group-hover/link:scale-110 transition-all duration-300" />
        </button>
      </div>
    </div>
  );
}

function CircuitBackground() {
  return (
    <div className="absolute inset-0 overflow-hidden pointer-events-none">
      <svg className="absolute w-full h-full" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000">
        <defs>
          <linearGradient id="gold-gradient" x1="0%" y1="0%" x2="100%" y2="100%">
            <stop offset="0%" stopColor="rgba(234, 179, 8, 0.8)" />
            <stop offset="50%" stopColor="rgba(234, 179, 8, 0.4)" />
            <stop offset="100%" stopColor="rgba(234, 179, 8, 0.8)" />
          </linearGradient>
          <pattern id="circuit-grid" x="0" y="0" width="200" height="200" patternUnits="userSpaceOnUse">
            <path
              d="M 0 100 L 50 100 M 150 100 L 200 100 M 100 0 L 100 50 M 100 150 L 100 200"
              stroke="rgba(234, 179, 8, 0.2)"
              strokeWidth="1"
              fill="none"
              className="circuit-trace"
            />
            <circle cx="100" cy="100" r="3" fill="rgba(234, 179, 8, 0.4)" className="animate-pulse-slow" />
          </pattern>
          <radialGradient id="core-glow" cx="50%" cy="50%" r="50%">
            <stop offset="0%" stopColor="rgba(234, 179, 8, 0.4)" />
            <stop offset="100%" stopColor="rgba(234, 179, 8, 0)" />
          </radialGradient>
          <filter id="glow">
            <feGaussianBlur stdDeviation="2" result="blur" />
            <feMerge>
              <feMergeNode in="blur" />
              <feMergeNode in="SourceGraphic" />
            </feMerge>
          </filter>
        </defs>

        {/* Background Grid Pattern */}
        <rect x="0" y="0" width="100%" height="100%" fill="url(#circuit-grid)" />

        {/* Multiple CPU Cores */}
        {[
          { x: 200, y: 200 },
          { x: 800, y: 200 },
          { x: 200, y: 800 },
          { x: 800, y: 800 },
          { x: 500, y: 500 },
        ].map((pos, i) => (
          <g key={`core-${i}`} transform={`translate(${pos.x - 30}, ${pos.y - 30})`}>
            <rect
              width="60"
              height="60"
              fill="rgba(234, 179, 8, 0.2)"
              stroke="url(#gold-gradient)"
              strokeWidth="2"
              className="animate-pulse-slow"
              style={{ animationDelay: `${i * 0.5}s` }}
            />
            <circle cx="30" cy="30" r="100" fill="url(#core-glow)" className="animate-pulse-slow" />
          </g>
        ))}

        {/* Dense Circuit Network */}
        {Array.from({ length: 20 }).map((_, i) => {
          const startX = (i % 5) * 200 + 100;
          const startY = Math.floor(i / 5) * 200 + 100;
          return (
            <g key={`network-${i}`}>
              <path
                d={`M ${startX} ${startY} 
                   Q ${startX + 100} ${startY - 50} ${startX + 200} ${startY}
                   M ${startX} ${startY}
                   Q ${startX - 50} ${startY + 100} ${startX} ${startY + 200}`}
                stroke="rgba(234, 179, 8, 0.3)"
                strokeWidth="1"
                fill="none"
                className="circuit-trace"
                style={{ animationDelay: `${i * 0.2}s` }}
              />
              <circle
                cx={startX}
                cy={startY}
                r="2"
                fill="rgba(234, 179, 8, 0.6)"
                className="animate-pulse-slow"
              />
            </g>
          );
        })}

        {/* Interconnecting Lines */}
        {Array.from({ length: 8 }).map((_, i) => {
          const angle = (i * Math.PI * 2) / 8;
          return Array.from({ length: 3 }).map((_, j) => {
            const radius = 150 + j * 100;
            const x1 = 500 + radius * Math.cos(angle);
            const y1 = 500 + radius * Math.sin(angle);
            const x2 = 500 + (radius + 50) * Math.cos(angle + Math.PI / 8);
            const y2 = 500 + (radius + 50) * Math.sin(angle + Math.PI / 8);
            return (
              <g key={`line-${i}-${j}`}>
                <path
                  d={`M ${x1} ${y1} Q ${(x1 + x2) / 2 + 30} ${(y1 + y2) / 2} ${x2} ${y2}`}
                  stroke="rgba(234, 179, 8, 0.3)"
                  strokeWidth="1"
                  fill="none"
                  className="circuit-trace"
                  style={{ animationDelay: `${i * 0.1 + j * 0.2}s` }}
                />
                <circle
                  r="2"
                  fill="rgba(234, 179, 8, 0.8)"
                  className="data-particle"
                >
                  <animateMotion
                    dur="3s"
                    repeatCount="indefinite"
                    path={`M ${x1} ${y1} Q ${(x1 + x2) / 2 + 30} ${(y1 + y2) / 2} ${x2} ${y2}`}
                    begin={`${i * 0.1 + j * 0.2}s`}
                  />
                </circle>
              </g>
            );
          });
        })}

        {/* Additional Connection Points */}
        {Array.from({ length: 25 }).map((_, i) => {
          const x = (i % 5) * 200 + 100;
          const y = Math.floor(i / 5) * 200 + 100;
          return (
            <circle
              key={`point-${i}`}
              cx={x}
              cy={y}
              r="3"
              fill="rgba(234, 179, 8, 0.4)"
              className="animate-pulse-slow"
              style={{ animationDelay: `${i * 0.1}s` }}
            />
          );
        })}
      </svg>
    </div>
  );
}

function CoreOfferings() {
  const services = [
    { 
      icon: Bot, 
      title: 'Elite AI Agent Development',
      description: 'Bespoke AI agents meticulously crafted to revolutionize your business operations.',
      features: [
        'Custom AI Strategy Development',
        'Advanced Natural Language Processing',
        'Real-time Learning & Adaptation',
        'Enterprise-grade Security'
      ]
    },
    { 
      icon: Globe, 
      title: 'Premium Web Development',
      description: 'Stunning, high-performance websites that command attention and drive conversions.',
      features: [
        'Luxury Brand Experience',
        'Advanced Analytics Integration',
        'SEO Optimization',
        'Mobile-first Design'
      ]
    },
    { 
      icon: Laptop, 
      title: 'Enterprise Web Applications',
      description: 'Sophisticated web applications engineered for unparalleled performance and scalability.',
      features: [
        'Custom Solution Architecture',
        'Real-time Data Processing',
        'Advanced Security Protocols',
        'Seamless Third-party Integration'
      ]
    },
    { 
      icon: Smartphone, 
      title: 'Elite Mobile Solutions',
      description: 'Premium mobile applications that deliver exceptional user experiences across all platforms.',
      features: [
        'Native Performance',
        'Cross-platform Excellence',
        'Offline Functionality',
        'Push Notification Systems'
      ]
    },
    { 
      icon: Mail, 
      title: 'Intelligent Email Systems',
      description: 'Advanced email automation that elevates your communication strategy.',
      features: [
        'AI-Powered Personalization',
        'Advanced Segmentation',
        'Performance Analytics',
        'A/B Testing Capabilities'
      ]
    },
    { 
      icon: Phone, 
      title: 'Advanced Call Intelligence',
      description: 'State-of-the-art call handling and automation solutions for enterprise needs.',
      features: [
        'Voice Recognition AI',
        'Smart Call Routing',
        'Real-time Analytics',
        'Custom Integration Options'
      ]
    },
  ];

  return (
    <section id="core-offerings" className="py-32 relative overflow-hidden">
      {/* Background Effects */}
      <div className="absolute inset-0 bg-gradient-to-b from-black via-green-950/5 to-black" />
      <div className="absolute inset-0">
        <div className="absolute top-0 left-1/4 w-96 h-96 bg-green-500/10 rounded-full blur-3xl" />
        <div className="absolute bottom-0 right-1/4 w-96 h-96 bg-yellow-500/10 rounded-full blur-3xl" />
      </div>

      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 relative">
        {/* Section Header */}
        <div className="text-center mb-20">
          <h2 className="text-4xl md:text-5xl font-bold mb-6 relative">
            <span className="absolute -inset-1 block rounded-lg bg-gradient-to-r from-green-500/20 to-yellow-500/20 blur" />
            <span className="relative bg-clip-text text-transparent bg-gradient-to-r from-green-400 via-yellow-300 to-green-400 animate-text-shimmer">
              Exclusive Solutions
            </span>
          </h2>
          <p className="text-xl text-gray-400 max-w-3xl mx-auto">
            Experience unparalleled excellence with our premium suite of solutions,
            meticulously crafted for discerning enterprises that demand perfection.
          </p>
        </div>

        {/* Services Grid */}
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
          {services.map((service, index) => (
            <ServiceCard key={index} {...service} index={index} />
          ))}
        </div>
      </div>
    </section>
  );
}

function ExperienceSection() {
  const scrollToOfferings = () => {
    const offeringsSection = document.querySelector('#core-offerings');
    offeringsSection?.scrollIntoView({ behavior: 'smooth' });
  };

  const stats = [
    { value: '98%', label: 'Client Satisfaction' },
    { value: '24/7', label: 'Premium Support' },
    { value: '100+', label: 'Enterprise Clients' },
    { value: '50+', label: 'AI Solutions Deployed' }
  ];

  return (
    <section className="py-32 relative overflow-hidden">
      <div className="absolute inset-0">
        <div className="absolute inset-0 bg-[url('https://images.unsplash.com/photo-1639322537228-f710d846310a')] bg-cover bg-center opacity-5" />
        <div className="absolute inset-0 bg-gradient-to-br from-emerald-900/20 via-black/50 to-yellow-900/20" />
      </div>

      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 relative">
        <div className="text-center">
          <div className="relative inline-block mb-8">
            <h2 className="relative text-4xl md:text-5xl font-bold bg-clip-text text-transparent bg-gradient-to-r from-emerald-400 via-yellow-300 to-emerald-400 animate-text-shimmer">
              Experience Unrivaled Excellence
            </h2>
          </div>

          <div className="relative max-w-3xl mx-auto mb-16">
            <p className="text-xl text-gray-300 leading-relaxed">
              Elevate your enterprise with our distinguished AI solutions. 
              Every interaction, every innovation, and every implementation is 
              crafted to deliver unprecedented sophistication and results.
            </p>
          </div>

          {/* Stats Grid */}
          <div className="grid grid-cols-2 md:grid-cols-4 gap-8 mb-16">
            {stats.map((stat, index) => (
              <div key={index} className="relative group">
                <div className="absolute inset-0 bg-gradient-to-r from-emerald-500/10 to-yellow-500/10 rounded-lg blur opacity-0 group-hover:opacity-100 transition-opacity duration-500" />
                <div className="relative p-6 rounded-lg border border-emerald-500/20 backdrop-blur-sm">
                  <div className="text-3xl font-bold text-emerald-400 group-hover:text-yellow-400 transition-colors duration-500">
                    {stat.value}
                  </div>
                  <div className="text-sm text-gray-400 mt-2">
                    {stat.label}
                  </div>
                </div>
              </div>
            ))}
          </div>

          <button 
            onClick={scrollToOfferings}
            className="luxury-button group"
          >
            <Crown className="w-5 h-5" />
            <span>Discover Our Premium Solutions</span>
            <ExternalLink className="w-5 h-5 group-hover:translate-x-1 transition-transform duration-300" />
          </button>
        </div>
      </div>
    </section>
  );
}

const contactFormSchema = z.object({
  name: z.string().min(2, 'Name must be at least 2 characters'),
  email: z.string().email('Invalid email address'),
  phone: z.string().optional(),
  message: z.string().min(10, 'Message must be at least 10 characters'),
  requestQuote: z.boolean().default(false),
});

type ContactFormData = z.infer<typeof contactFormSchema>;

function ToggleSwitch({ checked, onChange, id, label }: { checked: boolean; onChange: (checked: boolean) => void; id: string; label: string }) {
  return (
    <div className="flex items-center gap-3">
      <button
        type="button"
        role="switch"
        aria-checked={checked}
        id={id}
        onClick={() => onChange(!checked)}
        className={`relative inline-flex h-6 w-11 items-center rounded-full transition-colors duration-300 focus:outline-none focus:ring-2 focus:ring-emerald-500/20 ${
          checked ? 'bg-emerald-500' : 'bg-gray-700'
        }`}
      >
        <span className="sr-only">{label}</span>
        <span
          className={`inline-block h-4 w-4 transform rounded-full bg-white transition-transform duration-300 ${
            checked ? 'translate-x-6' : 'translate-x-1'
          }`}
        />
      </button>
      <label htmlFor={id} className="text-sm font-medium text-gray-300 select-none cursor-pointer">
        {label} <span className="text-emerald-400">{checked ? 'Yes' : 'No'}</span>
      </label>
    </div>
  );
}

function SuccessMessage({ onClose, onSendAnother }: { onClose: () => void, onSendAnother: () => void }) {
  return (
    <div className="relative bg-black/95 backdrop-blur-lg rounded-2xl border border-green-500/20 p-8 animate-fade-in">
      {/* Background glow effect */}
      <div className="absolute inset-0 bg-gradient-to-r from-green-500/10 to-yellow-500/10 rounded-2xl blur-xl" />
      
      {/* Content container */}
      <div className="relative z-10">
        {/* Close button */}
        <button
          onClick={onClose}
          className="absolute top-4 right-4 p-2 rounded-full bg-black/50 border border-green-500/20 
                   hover:border-yellow-500/30 transition-colors duration-300 group"
        >
          <X className="w-4 h-4 text-green-400 group-hover:text-yellow-400 transition-colors duration-300" />
        </button>

        {/* Success icon */}
        <div className="mb-6 w-16 h-16 mx-auto rounded-full bg-gradient-to-r from-green-500/20 to-yellow-500/20 
                      flex items-center justify-center relative">
          <div className="absolute inset-0 rounded-full bg-gradient-to-r from-green-500/10 to-yellow-500/10 blur-md" />
          <Send className="w-8 h-8 text-green-400 transform -rotate-45 relative z-10" />
        </div>

        {/* Message content */}
        <div className="text-center">
          <h3 className="text-2xl font-bold bg-clip-text text-transparent bg-gradient-to-r 
                       from-green-400 to-yellow-400 mb-3">
            Message Sent Successfully!
          </h3>
          <p className="text-gray-300 mb-6">
            Thank you for reaching out. We'll get back to you shortly.
          </p>
          
          {/* Action button */}
          <button
            onClick={onSendAnother}
            className="luxury-button"
          >
            <span>Send Another Message</span>
            <Send className="w-4 h-4 transform -rotate-45 group-hover:translate-x-1 
                         transition-transform duration-300" />
          </button>
        </div>
      </div>
    </div>
  );
}

function ContactForm() {
  const [formData, setFormData] = useState<ContactFormData>({
    name: '',
    email: '',
    phone: '',
    message: '',
    requestQuote: false
  });

  const [errors, setErrors] = useState<Partial<Record<keyof ContactFormData, string>>>({});
  const [isSubmitting, setIsSubmitting] = useState(false);
  const [submitted, setSubmitted] = useState(false);
  const [dataSaved, setDataSaved] = useState(false);

  useEffect(() => {
    if (dataSaved) {
      const timer = setTimeout(() => setDataSaved(false), 2000);
      return () => clearTimeout(timer);
    }
  }, [dataSaved]);

  const validateField = (name: keyof ContactFormData, value: string | boolean) => {
    try {
      if (name === 'phone') {
        if (!value) {
          setErrors(prev => ({ ...prev, [name]: undefined }));
          return;
        }
      }

      const schema = z.object({ [name]: contactFormSchema.shape[name] });
      schema.parse({ [name]: value });
      setErrors(prev => ({ ...prev, [name]: undefined }));
    } catch (error) {
      if (error instanceof z.ZodError) {
        setErrors(prev => ({
          ...prev,
          [name]: error.errors[0].message
        }));
      }
    }
  };

  const handleChange = (e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>) => {
    const { name, value } = e.target;
    setFormData(prev => ({
      ...prev,
      [name]: value
    }));
    setDataSaved(true);
    
    if (errors[name as keyof ContactFormData]) {
      setErrors(prev => ({
        ...prev,
        [name]: undefined
      }));
    }
  };

  const handleToggleQuote = (checked: boolean) => {
    setFormData(prev => ({
      ...prev,
      requestQuote: checked
    }));
    setDataSaved(true);
  };

  const handleBlur = (e: React.FocusEvent<HTMLInputElement | HTMLTextAreaElement>) => {
    const { name, value } = e.target;
    validateField(name as keyof ContactFormData, value);
  };

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    
    try {
      contactFormSchema.parse(formData);
      
      setIsSubmitting(true);
      
      await new Promise(resolve => setTimeout(resolve, 1500));
      
      console.log('Form submitted:', formData);
      
      setSubmitted(true);
    } catch (error) {
      if (error instanceof z.ZodError) {
        const newErrors: Record<string, string> = {};
        error.errors.forEach(err => {
          if (err.path[0]) {
            newErrors[err.path[0]] = err.message;
          }
        });
        setErrors(newErrors);
      }
    } finally {
      setIsSubmitting(false);
    }
  };

  const handleClose = () => {
    setFormData({
      name: '',
      email: '',
      phone: '',
      message: '',
      requestQuote: false
    });
    setSubmitted(false);
    setErrors({});
  };

  const handleSendAnother = () => {
    setFormData(prev => ({
      ...prev,
      message: ''
    }));
    setSubmitted(false);
    setErrors({});
  };

  if (submitted) {
    return (
      <div className="transform hover:scale-[1.01] transition-transform duration-700">
        <SuccessMessage onClose={handleClose} onSendAnother={handleSendAnother} />
      </div>
    );
  }

  return (
    <div className="relative transform hover:scale-[1.01] transition-transform duration-700">
      <div className="absolute inset-0 bg-gradient-to-r from-green-500/20 to-yellow-500/20 rounded-2xl blur-xl pointer-events-none" />
      
      {dataSaved && (
        <div className="absolute -top-12 left-1/2 transform -translate-x-1/2 bg-emerald-500/90 text-white px-4 py-2 rounded-lg text-sm font-medium z-20 animate-fade-in">
          Data saved
        </div>
      )}
      
      <form onSubmit={handleSubmit} className="relative z-10 bg-black/95 backdrop-blur-lg rounded-2xl border border-green-500/20 p-8 space-y-6">
        <div className="space-y-4">
          {[
            { name: 'name', icon: User, label: 'Full Name', type: 'text' },
            { name: 'email', icon: Mail, label: 'Email Address', type: 'email' },
            { name: 'phone', icon: Phone, label: 'Phone Number (Optional)', type: 'tel' },
          ].map((field) => (
            <div key={field.name} className="relative group">
              <div className="absolute inset-0 bg-gradient-to-r from-green-500/20 to-yellow-500/20 rounded-lg opacity-0 group-hover:opacity-100 transition-opacity duration-500 blur pointer-events-none" />
              
              <div className="relative z-10">
                <label className="flex items-center text-green-400 text-sm font-medium mb-2">
                  <field.icon className="w-4 h-4 mr-2" />
                  {field.label}
                </label>
                <input
                  type={field.type}
                  name={field.name}
                  value={formData[field.name as keyof ContactFormData]}
                  onChange={handleChange}
                  onBlur={handleBlur}
                  className={`w-full bg-black/90 border ${
                    errors[field.name]
                      ? 'border-red-500/50 focus:border-red-500/70 focus:ring-red-500/20'
                      : 'border-green-500/20 focus:border-yellow-500/50 focus:ring-green-500/20'
                  } rounded-lg px-4 py-3 text-white
                  focus:outline-none focus:ring-2
                  transition-all duration-500`}
                  placeholder={`Enter your ${field.label.toLowerCase()}`}
                  required={field.name !== 'phone'}
                />
                {errors[field.name] && (
                  <p className="mt-2 text-sm text-red-400">
                    {errors[field.name]}
                  </p>
                )}
              </div>
            </div>
          ))}

          <div className="relative group">
            <div className="absolute inset-0 bg-gradient-to-r from-green-500/20 to-yellow-500/20 rounded-lg opacity-0 group-hover:opacity-100 transition-opacity duration-500 blur pointer-events-none" />
            
            <div className="relative z-10">
              <label className="flex items-center text-green-400 text-sm font-medium mb-2">
                <MessageSquare className="w-4 h-4 mr-2" />
                Message
              </label>
              <textarea
                name="message"
                value={formData.message}
                onChange={handleChange}
                onBlur={handleBlur}
                rows={4}
                className={`w-full bg-black/90 border ${
                  errors.message
                    ? 'border-red-500/50 focus:border-red-500/70 focus:ring-red-500/20'
                    : 'border-green-500/20 focus:border-yellow-500/50 focus:ring-green-500/20'
                } rounded-lg px-4 py-3 text-white
                focus:outline-none focus:ring-2
                transition-all duration-500 resize-none`}
                placeholder="Tell us about your project"
                required
              />
              {errors.message && (
                <p className="mt-2 text-sm text-red-400">
                  {errors.message}
                </p>
              )}
            </div>
          </div>

          <div className="relative group pt-2">
            <ToggleSwitch
              checked={formData.requestQuote}
              onChange={handleToggleQuote}
              id="request-quote"
              label="Request a Quote"
            />
          </div>
        </div>

        <button
          type="submit"
          disabled={isSubmitting}
          className="luxury-button w-full justify-center disabled:opacity-70 disabled:cursor-not-allowed"
        >
          {isSubmitting ? (
            <>
              <div className="animate-spin rounded-full h-6 w-6 border-b-2 border-green-400"></div>
              <span>Sending...</span>
            </>
          ) : (
            <>
              <Send className="w-5 h-5" />
              <span>Send Message</span>
            </>
          )}
        </button>
      </form>
    </div>
  );
}

function ContactSection() {
  return (
    <section id="contact-section" className="py-24 relative overflow-hidden">
      {/* Background Effects */}
      <div className="absolute inset-0 bg-gradient-to-b from-black via-emerald-950/10 to-black" />
      
      {/* Ethereal Flames */}
      <div className="ethereal-flame ethereal-flame-left" />
      <div className="ethereal-flame ethereal-flame-right" />
      
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="text-center mb-16 relative">
          <div className="absolute inset-0 -top-20 mx-auto w-96 h-96 bg-emerald-500/20 rounded-full blur-3xl" />
          <div className="absolute inset-0 -top-20 mx-auto w-96 h-96 bg-yellow-500/20 rounded-full blur-3xl" />
          
          <h2 className="relative text-4xl md:text-5xl font-bold mb-4">
            <span className="bg-clip-text text-transparent bg-gradient-to-r from-emerald-400 via-yellow-300 to-emerald-400 animate-text-shimmer">
              Let's Create Something Extraordinary
            </span>
          </h2>
          <p className="relative text-xl text-gray-300 max-w-2xl mx-auto font-light">
            Transform your vision into reality with our cutting-edge AI solutions. 
            Reach out and let's begin crafting your future together.
          </p>
        </div>

        <div className="max-w-2xl mx-auto">
          <ContactForm />
        </div>
      </div>
    </section>
  );
}

function PhoneNumber({ number, icon: Icon, tooltip }: { number: string; icon: React.ElementType; tooltip: string }) {
  return (
    <div className="group flex items-center gap-3 text-gray-300 hover:text-yellow-400 transition-colors duration-300">
      <div className="p-2 rounded-lg bg-gradient-to-r from-emerald-500/10 to-yellow-500/10 
                    group-hover:from-emerald-500/20 group-hover:to-yellow-500/20 transition-all duration-300">
        <Icon className="w-4 h-4" />
      </div>
      <span className="phone-number-container">
        <span className="phone-number">{number}</span>
        <span className="phone-number-tooltip">{tooltip}</span>
      </span>
    </div>
  );
}

function Footer() {
  const currentYear = new Date().getFullYear();
  const [isVisible, setIsVisible] = useState(false);

  useEffect(() => {
    const toggleVisibility = () => {
      if (window.pageYOffset > 500) {
        setIsVisible(true);
      } else {
        setIsVisible(false);
      }
    };

    window.addEventListener('scroll', toggleVisibility);
    return () => window.removeEventListener('scroll', toggleVisibility);
  }, []);

  const scrollToTop = () => {
    window.scrollTo({
      top: 0,
      behavior: 'smooth'
    });
  };

  const scrollToSection = (sectionId: string) => {
    const section = document.getElementById(sectionId);
    if (section) {
      section.scrollIntoView({ behavior: 'smooth' });
    }
  };

  return (
    <footer className="relative py-24 overflow-hidden">
      {/* Gradient background */}
      <div className="absolute inset-0 bg-gradient-to-b from-black via-emerald-950/5 to-black" />
      
      {/* Animated background elements */}
      <div className="absolute inset-0">
        <div className="absolute bottom-0 left-1/4 w-96 h-96 bg-emerald-500/5 rounded-full blur-3xl animate-pulse-slow" />
        <div className="absolute bottom-0 right-1/4 w-96 h-96 bg-yellow-500/5 rounded-full blur-3xl animate-pulse-slow" 
             style={{ animationDelay: '1s' }} />
      </div>

      {/* Main footer content */}
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 relative">
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-12 mb-16">
          {/* Company Info */}
          <div className="space-y-6">
            <h3 className="text-3xl font-bold bg-clip-text text-transparent bg-gradient-to-r from-emerald-400 to-yellow-400 animate-text-shimmer">
              PRIMAL AI
            </h3>
            <p className="text-gray-300 leading-relaxed">
              Pioneering the future of AI technology with innovation and excellence. Transform your digital operations with our cutting-edge solutions.
            </p>
            <div className="flex space-x-4">
              {[Facebook, Twitter, Instagram, Linkedin].map((Icon, index) => (
                <button
                  key={index}
                  className="group relative p-2 rounded-lg bg-gradient-to-r from-emerald-500/10 to-yellow-500/10 
                           hover:from-emerald-500/20 hover:to-yellow-500/20 transition-all duration-300"
                >
                  <div className="absolute inset-0 rounded-lg bg-gradient-to-r from-emerald-500/20 to-yellow-500/20 opacity-0 
                                group-hover:opacity-100 blur transition-opacity duration-300" />
                  <Icon className="w-5 h-5 text-emerald-400 group-hover:text-yellow-400 transition-colors duration-300 relative z-10" />
                </button>
              ))}
            </div>
          </div>

          {/* Quick Links */}
          <div className="space-y-6">
            <h4 className="text-lg font-semibold text-emerald-400">Quick Links</h4>
            <ul className="space-y-3">
              {[
                { name: 'Services', section: 'core-offerings' },
                { name: 'Experience', section: 'experience-section' },
                { name: 'Contact', section: 'contact-section' },
              ].map((link) => (
                <li key={link.name}>
                  <button
                    onClick={() => scrollToSection(link.section)}
                    className="group text-gray-300 hover:text-yellow-400 transition-colors duration-300 flex items-center gap-2"
                  >
                    <ChevronRight className="w-4 h-4 transform group-hover:translate-x-1 transition-transform duration-300" />
                    <span>{link.name}</span>
                  </button>
                </li>
              ))}
            </ul>
          </div>

          {/* Contact Info */}
          <div className="space-y-6">
            <h4 className="text-lg font-semibold text-emerald-400">Connect With Us</h4>
            <div className="space-y-3">
              <a href="mailto:PRIMALSupport@gmail.com" 
                 className="group flex items-center gap-3 text-gray-300 hover:text-yellow-400 transition-colors duration-300">
                <div className="p-2 rounded-lg bg-gradient-to-r from-emerald-500/10 to-yellow-500/10 
                              group-hover:from-emerald-500/20 group-hover:to-yellow-500/20 transition-all duration-300">
                  <Mail className="w-4 h-4" />
                </div>
                <span>PRIMALSupport@gmail.com</span>
              </a>
              <PhoneNumber 
                number="+263 7154 25392"
                icon={Phone}
                tooltip="Cell Number"
              />
              <PhoneNumber 
                number="+44 74 7583 5548"
                icon={MessageCircle}
                tooltip="WhatsApp Number"
              />
              <div className="group flex items-center gap-3 text-gray-300">
                <div className="p-2 rounded-lg bg-gradient-to-r from-emerald-500/10 to-yellow-500/10 
                              group-hover:from-emerald-500/20 group-hover:to-yellow-500/20 transition-all duration-300">
                  <Building2 className="w-4 h-4" />
                </div>
                <span>Harare, Zimbabwe</span>
              </div>
            </div>
          </div>

          {/* Newsletter */}
          <div className="space-y-6">
            <h4 className="text-lg font-semibold text-emerald-400">Stay Updated</h4>
            <p className="text-gray-300">Subscribe to our newsletter for the latest updates and insights.</p>
            <form className="space-y-3">
              <div className="relative group">
                <div className="absolute -inset-0.5 bg-gradient-to-r from-emerald-500 to-yellow-500 rounded-lg opacity-50 blur group-hover:opacity-75 transition duration-300" />
                <input
                  type="email"
                  placeholder="Enter your email"
                  className="relative w-full px-4 py-2 bg-black border-none rounded-lg focus:outline-none focus:ring-2 focus:ring-emerald-500/50"
                />
              </div>
              <button
                type="submit"
                className="w-full luxury-button justify-center py-2"
              >
                <span>Subscribe</span>
                <Send className="w-4 h-4 transform -rotate-45" />
              </button>
            </form>
          </div>
        </div>

        {/* Bottom bar */}
        <div className="relative pt-8 mt-8 border-t border-emerald-900/30">
          <div className="flex flex-col md:flex-row justify-between items-center gap-4">
            <p className="text-gray-400 text-sm">
              © {currentYear} PRIMAL AI. All rights reserved.
            </p>
            <div className="flex gap-6 text-sm text-gray-400">
              <a href="#" className="hover:text-yellow-400 transition-colors duration-300">Privacy Policy</a>
              <a href="#" className="hover:text-yellow-400 transition-colors duration-300">Terms of Service</a>
              <a href="#" className="hover:text-yellow-400 transition-colors duration-300">Cookie Policy</a>
            </div>
          </div>
        </div>
      </div>

      {/* Scroll to top button - Positioned higher than the chat widget */}
      <button
        onClick={scrollToTop}
        className={`fixed right-8 bottom-32 p-2 rounded-full bg-gradient-to-r from-emerald-500/20 to-yellow-500/20 
                   backdrop-blur-sm border border-emerald-500/30 hover:border-yellow-500/30 
                   transition-all duration-300 group ${isVisible ? 'opacity-100 translate-y-0' : 'opacity-0 translate-y-10'}`}
      >
        <ArrowUpCircle className="w-6 h-6 text-emerald-400 group-hover:text-yellow-400 transition-colors duration-300" />
      </button>
    </footer>
  );
}

function App() {
  return (
    <div className="min-h-screen bg-black text-white">
      <header className="relative overflow-hidden h-screen">
        <div className="absolute inset-0 bg-gradient-to-br from-emerald-900/20 to-transparent" />
        <CircuitBackground />
        <Hero />
      </header>

      <CoreOfferings />
      <ExperienceSection />
      <ContactSection />
      <Footer />
    </div>
  );
}

export default App;